# flake8: noqa

# import apis into api package
from stadiamaps.api.geocoding_api import GeocodingApi
from stadiamaps.api.geospatial_api import GeospatialApi
from stadiamaps.api.routing_api import RoutingApi

