# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.travel_mode import TravelMode  # noqa: E501
from stadiamaps.rest import ApiException

class TestTravelMode(unittest.TestCase):
    """TravelMode unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTravelMode(self):
        """Test TravelMode"""
        # inst = TravelMode()

if __name__ == '__main__':
    unittest.main()
