# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.pelias_geo_json_properties import PeliasGeoJSONProperties  # noqa: E501
from stadiamaps.rest import ApiException

class TestPeliasGeoJSONProperties(unittest.TestCase):
    """PeliasGeoJSONProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PeliasGeoJSONProperties
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PeliasGeoJSONProperties`
        """
        model = stadiamaps.models.pelias_geo_json_properties.PeliasGeoJSONProperties()  # noqa: E501
        if include_optional :
            return PeliasGeoJSONProperties(
                gid = '', 
                source_id = '', 
                label = '', 
                layer = 'venue', 
                name = '', 
                accuracy = 'point', 
                addendum = { }, 
                continent = '', 
                continent_gid = '', 
                country = '', 
                country_gid = '', 
                neighbourhood = '', 
                neighbourhood_gid = '', 
                borough = '', 
                borough_gid = '', 
                postalcode = '', 
                street = '', 
                housenumber = '', 
                locality = '', 
                lecality_gid = '', 
                county = '', 
                region = '', 
                region_a = ''
            )
        else :
            return PeliasGeoJSONProperties(
        )
        """

    def testPeliasGeoJSONProperties(self):
        """Test PeliasGeoJSONProperties"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
