# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.geospatial_api import GeospatialApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestGeospatialApi(unittest.TestCase):
    """GeospatialApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.geospatial_api.GeospatialApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_elevation(self):
        """Test case for elevation

        Get the elevation profile along a polyline or at a point.  # noqa: E501
        """
        pass

    def test_tz_lookup(self):
        """Test case for tz_lookup

        Get the current time zone information for any point on earth.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
