# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import stadiamaps
from stadiamaps.models.locate_node_all_of import LocateNodeAllOf  # noqa: E501
from stadiamaps.rest import ApiException

class TestLocateNodeAllOf(unittest.TestCase):
    """LocateNodeAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test LocateNodeAllOf
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LocateNodeAllOf`
        """
        model = stadiamaps.models.locate_node_all_of.LocateNodeAllOf()  # noqa: E501
        if include_optional :
            return LocateNodeAllOf(
                traffic_signal = True, 
                type = 'street_intersection', 
                node_id = stadiamaps.models.node_id.nodeId(
                    id = 56, 
                    value = 56, 
                    tile_id = 56, 
                    level = 56, ), 
                access = stadiamaps.models.access.access(
                    golf_cart = True, 
                    wheelchair = True, 
                    taxi = True, 
                    hov = True, 
                    truck = True, 
                    emergency = True, 
                    pedestrian = True, 
                    car = True, 
                    bus = True, 
                    bicycle = True, 
                    motorcycle = True, 
                    moped = True, ), 
                edge_count = 56, 
                administrative = stadiamaps.models.administrative.administrative(
                    iso_3166_1 = '', 
                    country = '', 
                    iso_3166_2 = '', 
                    state = '', ), 
                intersection_type = 'regular', 
                density = 56, 
                local_edge_count = 56, 
                mode_change = True
            )
        else :
            return LocateNodeAllOf(
        )
        """

    def testLocateNodeAllOf(self):
        """Test LocateNodeAllOf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
