# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.routing_api import RoutingApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestRoutingApi(unittest.TestCase):
    """RoutingApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.routing_api.RoutingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_isochrone(self):
        """Test case for isochrone

        Calculate areas of equal travel time from a location.  # noqa: E501
        """
        pass

    def test_map_match(self):
        """Test case for map_match

        Match a recorded route to the road network.  # noqa: E501
        """
        pass

    def test_nearest_roads(self):
        """Test case for nearest_roads

        Find the nearest roads to the set of input locations.  # noqa: E501
        """
        pass

    def test_optimized_route(self):
        """Test case for optimized_route

        Calculate an optimized route between a known start and end point.  # noqa: E501
        """
        pass

    def test_route(self):
        """Test case for route

        Get turn by turn routing instructions between two or more locations.  # noqa: E501
        """
        pass

    def test_time_distance_matrix(self):
        """Test case for time_distance_matrix

        Calculate a time distance matrix for a grid of start and end points.  # noqa: E501
        """
        pass

    def test_trace_attributes(self):
        """Test case for trace_attributes

        Trace the attributes of roads visited on a route.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
