# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class CostingModel(str, Enum):
    """
    Costing models for determining the most optimal route to take. Note that bikeshare and motorcycle are still in beta. While Valhalla supports multimodal routing, we do not currently process transit data and have excluded it from the list. See https://valhalla.readthedocs.io/en/latest/api/turn-by-turn/api-reference/#costing-models for detailed descriptions of each model.
    """

    """
    allowed enum values
    """
    AUTO = 'auto'
    BUS = 'bus'
    TAXI = 'taxi'
    TRUCK = 'truck'
    BICYCLE = 'bicycle'
    BIKESHARE = 'bikeshare'
    MOTOR_SCOOTER = 'motor_scooter'
    MOTORCYCLE = 'motorcycle'
    PEDESTRIAN = 'pedestrian'

    @classmethod
    def from_json(cls, json_str: str) -> CostingModel:
        """Create an instance of CostingModel from a JSON string"""
        return CostingModel(json.loads(json_str))


