# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class Traversability(str, Enum):
    """
    The directions in which the edge is traversable.
    """

    """
    allowed enum values
    """
    FORWARD = 'forward'
    BACKWARD = 'backward'
    BOTH = 'both'

    @classmethod
    def from_json(cls, json_str: str) -> Traversability:
        """Create an instance of Traversability from a JSON string"""
        return Traversability(json.loads(json_str))


