# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.4
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class NodeType(str, Enum):
    """
    NodeType
    """

    """
    allowed enum values
    """
    STREET_INTERSECTION = 'street_intersection'
    GATE = 'gate'
    BOLLARD = 'bollard'
    TOLL_BOOTH = 'toll_booth'
    MULTI_USE_TRANSIT_STOP = 'multi_use_transit_stop'
    BIKE_SHARE = 'bike_share'
    PARKING = 'parking'
    MOTOR_WAY_JUNCTION = 'motor_way_junction'
    BORDER_CONTROL = 'border_control'

    @classmethod
    def from_json(cls, json_str: str) -> NodeType:
        """Create an instance of NodeType from a JSON string"""
        return NodeType(json.loads(json_str))


