# coding: utf-8

"""
    Stadia Maps Geospatial APIs

    The Stadia Maps Geospatial APIs provide you with the data you need to build awesome applications.  # noqa: E501

    The version of the OpenAPI document: 5.0.1
    Contact: support@stadiamaps.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest

import stadiamaps
from stadiamaps.api.geocoding_api import GeocodingApi  # noqa: E501
from stadiamaps.rest import ApiException


class TestGeocodingApi(unittest.TestCase):
    """GeocodingApi unit test stubs"""

    def setUp(self):
        self.api = stadiamaps.api.geocoding_api.GeocodingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_autocomplete(self):
        """Test case for autocomplete

        Search and geocode quickly based on partial input.  # noqa: E501
        """
        pass

    def test_place(self):
        """Test case for place

        Retrieve details of a place using its GID.  # noqa: E501
        """
        pass

    def test_reverse(self):
        """Test case for reverse

        Find places and addresses near geographic coordinates (reverse geocoding).  # noqa: E501
        """
        pass

    def test_search(self):
        """Test case for search

        Search for location and other info using a place name or address (forward geocoding).  # noqa: E501
        """
        pass

    def test_search_structured(self):
        """Test case for search_structured

        Find locations matching components (structured forward geocoding).  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
